@@ -1,4 +1,4 @@
-## Copyright (C) 2009 Christian Fischer <cfischer@itm.uni-stuttgart.de>
+## Copyright (C) 2009-2010 Christian Fischer <cfischer@itm.uni-stuttgart.de>
 ## Copyright (C) 1996, 1997 R. Storn
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -147,7 +147,7 @@ if nargin >= 2,			# Read control arguments
   if nargin > 2,
     ctl = struct (varargin{:});
   else
-    ctl = nth (varargin, va_arg_cnt++);
+    ctl = varargin{va_arg_cnt++};
   end
   if isnumeric (ctl)
     if length (ctl)>=1 && !isnan (ctl(1)), XVmin  = ctl(1); end
@@ -199,17 +199,17 @@ end
 if (NP < 5)
   error("Population size NP must be bigger than 5.")
 end
-if ((F <= 0) | (F > 2))
+if ((F <= 0) || (F > 2))
   error("Difference Factor F out of range (0,2].")
 end
-if ((CR < 0) | (CR > 1))
+if ((CR < 0) || (CR > 1))
   error("CR value out of range [0,1].")
 end
 if (maxiter <= 0)
   error("maxiter must be positive.")
 end
 if (maxnfe <= 0)
-  error("maxiter must be positive.")
+  error("maxnfe must be positive.")
 end
 refresh = floor(abs(refresh));
 
@@ -264,7 +264,7 @@ rot = 0:1:NP-1;                 # rotating index array (size NP)
 rotd= 0:1:D-1;                  # rotating index array (size D)
 
 iter = 1;
-while ((iter < maxiter) & (nfeval < maxnfe) &  (bestval > VTR)  & ...
+while ((iter < maxiter) && (nfeval < maxnfe) &&  (bestval > VTR)  && ...
        ((abs (max (val) - bestval) / max (1, abs (max (val))) > tol)))
   popold = pop;                   # save the old population
   wold   = w;                     # save the old weighting factors
@@ -336,7 +336,7 @@ while ((iter < maxiter) & (nfeval < maxnfe) &  (bestval > VTR)  & ...
                                           # do wrap around
 	  [x, ix] = min (val(neigh_ind));     # find the local best and its index
 	  bm_n(i,:) = popold(neigh_ind(ix),:); # copy the data from the local best
-	  neigh_ind(ix) = [];                 # remove "i"
+	  neigh_ind(nr+1) = [];                 # remove "i"
 	  pq = neigh_ind(randperm (length (neigh_ind)));
                                         # permutation of the remaining ind.
 	  lpm1(i,:) = popold(pq(1),:);        # create the local pop member matrix
@@ -454,4 +454,3 @@ endfunction
 %! ctl.XVmax = [ 3  3];
 %! ## and solve it with de_min
 %! [x, obj_value, nfeval, convergence] = de_min (f, ctl)
-
